@@ -2,8 +2,13 @@ package Mouse::Meta::Method::Accessor;
 use Mouse::Util; # enables strict and warnings
 use Scalar::Util qw(blessed);
 
+sub _inline_slot{
+    my(undef, $self_var, $attr_name) = @_;
+    return sprintf '%s->{q{%s}}', $self_var, $attr_name;
+}
+
 sub _generate_accessor{
-    my (undef, $attribute, $class, $type) = @_;
+    my ($method_class, $attribute, $class, $type) = @_;
 
     my $name          = $attribute->name;
     my $default       = $attribute->default;
@@ -17,8 +22,7 @@ sub _generate_accessor{
     my $compiled_type_constraint = defined($constraint) ? $constraint->_compiled_type_constraint : undef;
 
     my $self  = '$_[0]';
-    my $key   = "q{$name}";
-    my $slot  = "$self\->{$key}";
+    my $slot  = $method_class->_inline_slot($self, $name);;
 
     $type ||= 'accessor';
 
@@ -162,28 +166,19 @@ sub _generate_clearer {
     };
 }
 
-sub _generate_delegation{
-    my (undef, $attribute, $class, $reader, $handle_name, $method_to_call) = @_;
-
-    return sub {
-        my $instance = shift;
-        my $proxy    = $instance->$reader();
-
-        my $error = !defined($proxy)                ? ' is not defined'
-                  : ref($proxy) && !blessed($proxy) ? qq{ is not an object (got '$proxy')}
-                                                    : undef;
-        if ($error) {
-            $instance->meta->throw_error(
-                "Cannot delegate $handle_name to $method_to_call because "
-                    . "the value of "
-                    . $attribute->name
-                    . $error
-             );
-        }
-        $proxy->$method_to_call(@_);
-    };
-}
-
-
 1;
 __END__
+
+=head1 NAME
+
+Mouse::Meta::Method::Accessor - A Mouse method generator for accessors
+
+=head1 VERSION
+
+This document describes Mouse version 0.40_01
+
+=head1 SEE ALSO
+
+L<Moose::Meta::Method::Accessor>
+
+=cut
