@@ -114,3 +114,16 @@ sub _apply_methods{
 1;
 __END__
 
+=head1 NAME
+
+Mouse::Meta::Role::Composite - An object to represent the set of roles
+
+=head1 VERSION
+
+This document describes Mouse version 0.40_01
+
+=head1 SEE ALSO
+
+L<Moose::Meta::Role::Composite>
+
+=cut
