@@ -1,11 +1,14 @@
 package Mouse::Role;
-use Mouse::Util qw(not_supported); # enables strict and warnings
+use Mouse::Exporter; # enables strict and warnings
 
-use Carp qw(confess);
+our $VERSION = '0.40_01';
+
+use Carp         qw(confess);
 use Scalar::Util qw(blessed);
 
+use Mouse::Util  qw(not_supported);
+use Mouse::Meta::Role;
 use Mouse ();
-use Mouse::Exporter;
 
 Mouse::Exporter->setup_import_methods(
     as_is => [qw(
@@ -138,6 +141,10 @@ __END__
 
 Mouse::Role - The Mouse Role
 
+=head1 VERSION
+
+This document describes Mouse version 0.40_01
+
 =head1 SYNOPSIS
 
     package MyRole;
