@@ -1,9 +1,31 @@
 package Mouse::Util;
 use Mouse::Exporter; # enables strict and warnings
 
+BEGIN{
+    # Because Mouse::Util is loaded first in all the Mouse sub-modules,
+    # XS loader is placed here, not in Mouse.pm.
+
+    our $VERSION = '0.40_01';
+
+    my $need_pp = !!$ENV{MOUSE_PUREPERL};
+
+    if(!$need_pp && !exists $INC{'Mouse/PurePerl.pm'}){
+        local $@;
+        $need_pp = !eval{
+            require XSLoader;
+            XSLoader::load('Mouse', $VERSION);
+        };
+        #warn $@ if $@;
+    }
+
+    if($need_pp){
+        require 'Mouse/PurePerl.pm'; # we don't want to create its namespace
+    }
+}
+
+
 use Carp qw(confess);
 use Scalar::Util qw(blessed);
-use B ();
 
 use constant _MOUSE_VERBOSE => !!$ENV{MOUSE_VERBOSE};
 
@@ -22,6 +44,7 @@ Mouse::Exporter->setup_import_methods(
         get_code_info
 
         get_code_package
+        get_code_ref
 
         not_supported
 
@@ -34,7 +57,6 @@ Mouse::Exporter->setup_import_methods(
         # The ':meta' group is 'use metaclass' for Mouse
         meta    => [qw(does meta dump _MOUSE_VERBOSE)],
     },
-    _export_to_main => 1,
 );
 
 # aliases as public APIs
@@ -108,32 +130,6 @@ BEGIN {
     *get_linear_isa = $impl;
 }
 
-{ # taken from Sub::Identify
-    sub get_code_info($) {
-        my ($coderef) = @_;
-        ref($coderef) or return;
-
-        my $cv = B::svref_2object($coderef);
-        $cv->isa('B::CV') or return;
-
-        my $gv = $cv->GV;
-        $gv->isa('B::GV') or return;
-
-        return ($gv->STASH->NAME, $gv->NAME);
-    }
-
-    sub get_code_package{
-        my($coderef) = @_;
-
-        my $cv = B::svref_2object($coderef);
-        $cv->isa('B::CV') or return '';
-
-        my $gv = $cv->GV;
-        $gv->isa('B::GV') or return '';
-
-        return $gv->STASH->NAME;
-    }
-}
 
 # taken from Mouse::Util (0.90)
 {
@@ -164,6 +160,8 @@ BEGIN {
 
 # Utilities from Class::MOP
 
+sub get_code_info;
+sub get_code_package;
 
 # taken from Class/MOP.pm
 sub is_valid_class_name {
@@ -235,37 +233,7 @@ sub load_class {
     return 1;
 }
 
-
-sub is_class_loaded {
-    my $class = shift;
-
-    return 0 if ref($class) || !defined($class) || !length($class);
-
-    # walk the symbol table tree to avoid autovififying
-    # \*{${main::}{"Foo::"}} == \*main::Foo::
-
-    my $pack = \%::;
-    foreach my $part (split('::', $class)) {
-        my $entry = \$pack->{$part . '::'};
-        return 0 if ref($entry) ne 'GLOB';
-        $pack = *{$entry}{HASH} or return 0;
-    }
-
-    # check for $VERSION or @ISA
-    return 1 if exists $pack->{VERSION}
-             && defined *{$pack->{VERSION}}{SCALAR} && defined ${ $pack->{VERSION} };
-    return 1 if exists $pack->{ISA}
-             && defined *{$pack->{ISA}}{ARRAY} && @{ $pack->{ISA} } != 0;
-
-    # check for any method
-    foreach my $name( keys %{$pack} ) {
-        my $entry = \$pack->{$name};
-        return 1 if ref($entry) ne 'GLOB' || defined *{$entry}{CODE};
-    }
-
-    # fail
-    return 0;
-}
+sub is_class_loaded;
 
 
 sub apply_all_roles {
@@ -284,8 +252,7 @@ sub apply_all_roles {
         my $role_name = $roles[-1][0];
         load_class($role_name);
 
-        my $metarole = get_metaclass_by_name($role_name);
-        ( $metarole && $metarole->isa('Mouse::Meta::Role') )
+        Mouse::Util::TypeConstraints::_is_a_metarole( get_metaclass_by_name($role_name) )
             || $applicant->meta->throw_error("You can only consume roles, $role_name(".$role_name->meta.") is not a Mouse role");
     }
 
@@ -352,6 +319,10 @@ __END__
 
 Mouse::Util - Features, with or without their dependencies
 
+=head1 VERSION
+
+This document describes Mouse version 0.40_01
+
 =head1 IMPLEMENTATIONS FOR
 
 =head2 Moose::Util
